==> deepin-terminal_5.4.33.orig.tar.xz: deepin-terminal-5.4.33/3rdparty/terminalwidget/lib/translations/terminalwidget_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1279"/>
        <source>Size: XXX x XXX</source>
        <translation>ཆེ་ཆུང་།  XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1291"/>
        <source>Size: %1 x %2</source>
        <translation>ཆེ་ཆུང་། %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3178"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;ཕྱིར་འདོན་འདི་ Ctrl+S &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;ཡིས་སྐབས་སྡོད་བྱས། &lt;/a&gt; འདི་  &lt;b&gt;Ctrl+Q&lt;/b&gt; ལྟར་བསྐྱར་གསོ་བྱ་རྒྱུ་&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1105"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>སྤྱོད་ཆོག་པའི་མཐེབ་རྟགས་སྒྱུར་བའི་རེའུ་མིག་མིན་འདུག མཐེབ་བཀྱག་དེ་ཡིག་རྟགས་སུ་བསྒྱུར་ནས་མཐའ་སྣེར་སྐུར་དགོས་པའི་ཆ་འཕྲིན་རྙེད་ཀྱི་མིན་འདུག</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="278"/>
        <location filename="../ColorScheme.cpp" line="293"/>
        <source>Un-named Color Scheme</source>
        <translation>མིང་མེད་པའི་ཚོས་སྡེབ།</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="464"/>
        <source>Accessible Color Scheme</source>
        <translation>སྤྱོད་ཆོག་པའི་ཚོས་སྡེབ།</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="538"/>
        <source>Open link</source>
        <translation>སྦྲེལ་མཐུད་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="539"/>
        <source>Copy link</source>
        <translation>སྦྲེལ་མཐུད་པར་སློག</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="543"/>
        <source>Send email to...</source>
        <translation>སྦྲག་ཡིག་...ལ་སྐུར་བ།</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="544"/>
        <source>Copy email address</source>
        <translation>སྦྲག་ཡིག་གནས་ཡུལ་པར་སློག</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="451"/>
        <source>Color Scheme Error</source>
        <translation>ཚོས་སྡེབ་ནོར་བ།</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="452"/>
        <source>Cannot load color scheme: %1</source>
        <translation>ཚོས་སྡེབ་ %1སྣོན་འཇུག་བྱེད་ཐབས་མེད།</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>ཆེ་བྲིས་ཆུང་བྲིས་སྙོམ་འགྲིག་བྱ་དགོས།</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>ཚད་ལྡན་མཚོན་ཚུལ།</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>སྙོམ་འགྲིག་ཐུབ་པའི་ཚན་པ་ཚང་མ་གསལ་ཚད་མཐོ།</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>འཚོལ་ཞིབ་ཚན་བྱང་།</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>འཚོལ་བ།</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>

==> deepin-terminal_5.9.40+dfsg.orig.tar.xz: deepin-terminal-5.9.40/3rdparty/terminalwidget/lib/translations/terminalwidget_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1279"/>
        <source>Size: XXX x XXX</source>
        <translation>ཆེ་ཆུང་།  XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1291"/>
        <source>Size: %1 x %2</source>
        <translation>ཆེ་ཆུང་། %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3178"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;ཕྱིར་འདོན་འདི་ Ctrl+S &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;ཡིས་སྐབས་སྡོད་བྱས། &lt;/a&gt; འདི་  &lt;b&gt;Ctrl+Q&lt;/b&gt; ལྟར་བསྐྱར་གསོ་བྱ་རྒྱུ་&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1105"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>སྤྱོད་ཆོག་པའི་མཐེབ་རྟགས་སྒྱུར་བའི་རེའུ་མིག་མིན་འདུག མཐེབ་བཀྱག་དེ་ཡིག་རྟགས་སུ་བསྒྱུར་ནས་མཐའ་སྣེར་སྐུར་དགོས་པའི་ཆ་འཕྲིན་རྙེད་ཀྱི་མིན་འདུག</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="278"/>
        <location filename="../ColorScheme.cpp" line="293"/>
        <source>Un-named Color Scheme</source>
        <translation>མིང་མེད་པའི་ཚོས་སྡེབ།</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="464"/>
        <source>Accessible Color Scheme</source>
        <translation>སྤྱོད་ཆོག་པའི་ཚོས་སྡེབ།</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="538"/>
        <source>Open link</source>
        <translation>སྦྲེལ་མཐུད་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="539"/>
        <source>Copy link</source>
        <translation>སྦྲེལ་མཐུད་པར་སློག</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="543"/>
        <source>Send email to...</source>
        <translation>སྦྲག་ཡིག་...ལ་སྐུར་བ།</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="544"/>
        <source>Copy email address</source>
        <translation>སྦྲག་ཡིག་གནས་ཡུལ་པར་སློག</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="451"/>
        <source>Color Scheme Error</source>
        <translation>ཚོས་སྡེབ་ནོར་བ།</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="452"/>
        <source>Cannot load color scheme: %1</source>
        <translation>ཚོས་སྡེབ་ %1སྣོན་འཇུག་བྱེད་ཐབས་མེད།</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>ཆེ་བྲིས་ཆུང་བྲིས་སྙོམ་འགྲིག་བྱ་དགོས།</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>ཚད་ལྡན་མཚོན་ཚུལ།</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>སྙོམ་འགྲིག་ཐུབ་པའི་ཚན་པ་ཚང་མ་གསལ་ཚད་མཐོ།</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>འཚོལ་ཞིབ་ཚན་བྱང་།</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>འཚོལ་བ།</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>
